@@ -309,15 +309,12 @@ class Config
         // Lists
         Blacklist blacklist;
         Blacklist ignorelist;
-        Blacklist gamehasdlc;
 
         // Cloud save options
         std::vector<std::string> cloudWhiteList;
         std::vector<std::string> cloudBlackList;
         bool bCloudForce;
 
-        std::string sGameHasDLCList;
-
         // Integers
         int iRetries;
         unsigned int iThreads;
